==> activity-center-api-3.3.15-cf-sources.jar: cn/com/duiba/activity/center/api/dto/creditsfarm/CreditsFarmOptionDto.java <==
package cn.com.duiba.activity.center.api.dto.creditsfarm;

import java.io.Serializable;

/**
* 积分农场奖品表
*/
public class CreditsFarmOptionDto implements Serializable {

    private static final long serialVersionUID = -3584570390822232003L;
    /**
    * 主键
    */
    private Long id;

    /**
    * 活动id
    */
    private Long actId;

    /**
    * 种子id
    */
    private Long seedId;

    /**
     * 种子类型：apple-苹果 tomato-土豆 rice-大米 peanut-花生
     */
    private String seedType;

    /**
    * 奖品名称
    */
    private String optionName;

    /**
    * 供货价（分）
    */
    private Integer optionPrice;

    /**
    * 奖品数量
    */
    private Integer optionCount;

    /**
     * 奖品图片
     */
    private String optionPic;

    /**
    * 商品id
    */
    private Long itemId;

    /**
    * 库存id
    */
    private Long stockId;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public void setSeedId(Long seedId) {
        this.seedId = seedId;
    }

    public Long getSeedId() {
        return seedId;
    }

    public void setOptionName(String optionName) {
        this.optionName = optionName;
    }

    public String getOptionName() {
        return optionName;
    }

    public void setOptionPrice(Integer optionPrice) {
        this.optionPrice = optionPrice;
    }

    public Integer getOptionPrice() {
        return optionPrice;
    }

    public void setOptionCount(Integer optionCount) {
        this.optionCount = optionCount;
    }

    public Integer getOptionCount() {
        return optionCount;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Long getStockId() {
        return stockId;
    }

    public String getOptionPic() {
        return optionPic;
    }

    public void setOptionPic(String optionPic) {
        this.optionPic = optionPic;
    }

    public String getSeedType() {
        return seedType;
    }

    public void setSeedType(String seedType) {
        this.seedType = seedType;
    }
}

==> activity-center-api-3.3.18-cf-sources.jar: cn/com/duiba/activity/center/api/dto/creditsfarm/CreditsFarmOptionDto.java <==
package cn.com.duiba.activity.center.api.dto.creditsfarm;

import java.io.Serializable;

/**
* 积分农场奖品表
*/
public class CreditsFarmOptionDto implements Serializable {

    private static final long serialVersionUID = -3584570390822232003L;
    /**
    * 主键
    */
    private Long id;

    /**
    * 活动id
    */
    private Long actId;

    /**
    * 种子id
    */
    private Long seedId;

    /**
     * 应用id
     */
    private Long appId;

    /**
     * 种子类型：apple-苹果 tomato-土豆 rice-大米 peanut-花生
     */
    private Integer seedType;

    /**
    * 奖品名称
    */
    private String optionName;

    /**
    * 供货价（分）
    */
    private Integer optionPrice;

    /**
    * 奖品数量
    */
    private Integer optionCount;

    /**
     * 奖品图片
     */
    private String optionPic;

    /**
    * 商品id
    */
    private Long itemId;

    /**
    * 库存id
    */
    private Long stockId;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public void setSeedId(Long seedId) {
        this.seedId = seedId;
    }

    public Long getSeedId() {
        return seedId;
    }

    public void setOptionName(String optionName) {
        this.optionName = optionName;
    }

    public String getOptionName() {
        return optionName;
    }

    public void setOptionPrice(Integer optionPrice) {
        this.optionPrice = optionPrice;
    }

    public Integer getOptionPrice() {
        return optionPrice;
    }

    public void setOptionCount(Integer optionCount) {
        this.optionCount = optionCount;
    }

    public Integer getOptionCount() {
        return optionCount;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Long getStockId() {
        return stockId;
    }

    public String getOptionPic() {
        return optionPic;
    }

    public void setOptionPic(String optionPic) {
        this.optionPic = optionPic;
    }

    public Integer getSeedType() {
        return seedType;
    }

    public void setSeedType(Integer seedType) {
        this.seedType = seedType;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }
}
